<?php
/**
 * @author		Scorpion Computers and Software
 * @copyright   Copyright (C) Scorpion Computers and Software, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; http://www.gnu.org/copyleft/gpl.html
 * @email       info@ScorpionComputers.nl
 */

defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Helper\ModuleHelper;
use Joomla\CMS\Date\Date;
use Joomla\Module\ScorpionRsformstats\Site\Helper\RsFormStatsHelper;

// Include the helper functions only once
require_once dirname(__FILE__) . '/src/Helper/RsFormStatsHelper.php';

$app = Factory::getApplication();
$db = Factory::getContainer()->get('DatabaseDriver');

// Get module parameters
$formId = $params->get('formid');
$periodType = $params->get('period_type', 'relative');
$relativePeriod = $params->get('relative_period', 7);
$startDateParam = $params->get('start_date');
$endDateParam = $params->get('end_date');
$textBefore = $params->get('display_text_before', 'Submissions:');
$textAfter = $params->get('display_text_after', '');

// Ensure a form is selected
if (empty($formId)) {
    echo 'Please select an RSForm! Pro form in the module settings.';
    return;
}

// Calculate date range
$dateNow = new Date('now', Factory::getConfig()->get('offset'));
$endDate = clone $dateNow;
$startDate = clone $dateNow;

if ($periodType === 'absolute') {
    if (!empty($startDateParam)) {
        try {
            $startDate = new Date($startDateParam, Factory::getConfig()->get('offset'));
        } catch (Exception $e) {
            // Handle invalid date format, perhaps log or default
            echo 'Invalid start date format.';
            return;
        }
    } else {
        // Default start date if not provided for absolute?
        // Maybe require it or default to form creation date?
        // For now, let's echo an error.
        echo 'Start date is required for absolute period.';
        return;
    }
    if (!empty($endDateParam)) {
        try {
            $endDate = new Date($endDateParam, Factory::getConfig()->get('offset'));
            // Add one day to make the end date inclusive for the query
            $endDate->modify('+1 day');
        } catch (Exception $e) {
            // Handle invalid date format
            echo 'Invalid end date format.';
            return;
        }
    } else {
         // Default to today if end date is not set
         $endDate->modify('+1 day');
    }

    // Ensure start date is before end date
    if ($startDate >= $endDate) {
        echo 'Start date must be before end date.';
        return;
    }

} else { // Relative period
    $daysToSubtract = (int) $relativePeriod;
    $startDate->modify('-' . $daysToSubtract . ' day');
    // For relative period, end date is 'now' + 1 day for the query
    $endDate->modify('+1 day');
}

// Get submission count
$submissionCount = RsFormStatsHelper::getSubmissionCount($db, $formId, $startDate->format('Y-m-d H:i:s', true), $endDate->format('Y-m-d H:i:s', true));

// Load the template
require ModuleHelper::getLayoutPath('mod_scorpion_rsformstats', $params->get('layout', 'default')); 