<?php
/**
 * @author		Scorpion Computers and Software
 * @copyright   Copyright (C) Scorpion Computers and Software, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; http://www.gnu.org/copyleft/gpl.html
 * @email       info@ScorpionComputers.nl
 */

namespace Joomla\Module\ScorpionRsformstats\Site\Helper;

defined('_JEXEC') or die;

use Joomla\Database\DatabaseDriver;

/**
 * Helper class for mod_scorpion_rsformstats module
 */
class RsFormStatsHelper
{
    /**
     * Get the count of submissions for a specific form within a date range.
     *
     * @param   DatabaseDriver  $db         The database driver instance.
     * @param   int             $formId     The ID of the RSForm! Pro form.
     * @param   string          $startDate  The start date (Y-m-d H:i:s).
     * @param   string          $endDate    The end date (Y-m-d H:i:s).
     *
     * @return  int  The number of submissions.
     */
    public static function getSubmissionCount(DatabaseDriver $db, int $formId, string $startDate, string $endDate): int
    {
        $query = $db->getQuery(true)
            ->select('COUNT(s.SubmissionId)')
            ->from($db->quoteName('#__rsform_submissions', 's'))
            ->where($db->quoteName('s.FormId') . ' = ' . $db->quote($formId))
            ->where($db->quoteName('s.DateSubmitted') . ' >= ' . $db->quote($startDate))
            ->where($db->quoteName('s.DateSubmitted') . ' < ' . $db->quote($endDate)); // Use '<' as end date is exclusive upper bound

        $db->setQuery($query);

        try {
            $count = (int) $db->loadResult();
        } catch (\Exception $e) {
            // Log error or display a message in development mode
            // Factory::getApplication()->enqueueMessage('Database error: ' . $e->getMessage(), 'error');
            return 0; // Return 0 on error
        }

        return $count;
    }
} 